#
# spec file for package mate-session-manager
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _version 1.16
Name:           mate-session-manager
Version:        1.16.0
Release:        1.1
Summary:        MATE Session Manager
License:        GPL-2.0+
Group:          System/GUI/Other
Url:            http://mate-desktop.org/
Source:         http://pub.mate-desktop.org/releases/%{_version}/%{name}-%{version}.tar.xz
# Not an upstream file. Only proposes upstream packages:
Source1:        mate-session-manager-upstream-mate_defaults.conf
# Some documentation for people writing branding packages, shipped in the branding-upstream package.
Source2:        README.Gsettings-overrides
BuildRequires:  hicolor-icon-theme
BuildRequires:  mate-common >= %{_version}
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.14
BuildRequires:  pkgconfig(ice)
BuildRequires:  pkgconfig(sm)
BuildRequires:  pkgconfig(xau)
BuildRequires:  pkgconfig(xext)
Requires:       %{name}-branding >= %{_version}
Requires:       %{name}-gschemas >= %{version}
Recommends:     %{name}-lang
%glib2_gsettings_schema_requires
%if 0%{?suse_version} > 1310
BuildRequires:  pkgconfig(libsystemd)
%else
BuildRequires:  pkgconfig(libsystemd-login)
%endif

%description
This package contains a session that can be started from a display
manager such as MDM. It will load all necessary applications for a
full-featured user session.

%lang_package

%package branding-upstream
Summary:        Upstream definitions of default settings and applications
Group:          System/Libraries
Requires:       %{name} = %{version}
Supplements:    packageand(%{name}:branding-upstream)
Conflicts:      otherproviders(%{name}-branding)
Provides:       %{name}-branding = %{version}
BuildArch:      noarch
#BRAND: The /etc/mate_defaults.conf allows to define arbitrary
#BRAND: applications as preferred defaults.
#BRAND: A /usr/share/glib-2.0/schemas/$NAME.gschema.override file can
#BRAND: be used to override the default value for GSettings keys. See
#BRAND: README.Gsettings-overrides for more details. The branding
#BRAND: package should then have proper Requires for features changed
#BRAND: with such an override file.

%description -n mate-session-manager-branding-upstream
This package provides upstream defaults for settings stored with
GSettings and applications used by the MIME system.

%package gschemas
Summary:        MATE Session Manager GSchemas
Group:          System/Libraries
%glib2_gsettings_schema_requires

%description gschemas
This package provides the GSettings schemas for
MATE Session Manager.

%prep
%setup -q
cp -a %{SOURCE2} .
cp -a %{SOURCE1} mate_defaults.conf

%build
NOCONFIGURE=1 mate-autogen
%configure \
  --disable-static        \
  --enable-ipv6           \
  --with-default-wm=marco \
  --with-systemd=yes
make %{?_smp_mflags}

%install
%make_install
%find_lang %{name} %{?no_lang_C}

%suse_update_desktop_file mate-session-properties
%suse_update_desktop_file %{buildroot}%{_datadir}/xsessions/mate.desktop

install -Dpm 0644 mate_defaults.conf %{buildroot}%{_sysconfdir}/mate_defaults.conf

%post
%icon_theme_cache_post

%postun
%icon_theme_cache_postun

%post gschemas
%glib2_gsettings_schema_post

%postun gschemas
%glib2_gsettings_schema_postun

%files
%defattr(-,root,root)
%doc COPYING NEWS README
%{_bindir}/mate-*
%{_datadir}/%{name}/
%{_datadir}/xsessions/mate.desktop
%{_datadir}/applications/mate-session-properties.desktop
%{_datadir}/icons/hicolor/*/apps/mate-session-properties.*
%{_mandir}/man?/mate-*.?%{?ext_man}

%files lang -f %{name}.lang
%defattr(-,root,root)

%files branding-upstream
%defattr(-,root,root)
%doc README.Gsettings-overrides
%config(noreplace) %{_sysconfdir}/mate_defaults.conf

%files gschemas
%defattr(-,root,root)
%{_datadir}/glib-2.0/schemas/*.xml

%changelog
* Tue Sep 20 2016 sor.alexei@meowr.ru
- Update to version 1.16.0:
  * Move to GTK+3 (require GTK+ >= 3.14), drop GTK+2 code and
  - -with-gtk build option.
  * Update translations.
* Sun Aug 14 2016 sor.alexei@meowr.ru
- Update to version 1.14.1:
  * GTK+3: Fix critical warning in logout/shutdown dialogues.
  * Update translations.
* Sat Apr  9 2016 sor.alexei@meowr.ru
- Update to version 1.14.0:
  * Add Changelog generation.
* Tue Apr  5 2016 sor.alexei@meowr.ru
- Update to version 1.13.0:
  * Drop MateConf migration script.
  * Gtk3: Fix some deprecations.
  * Some more fixes and cleanups.
  * Update translations.
- Switch to Gtk3.
* Tue Apr  5 2016 sor.alexei@meowr.ru
- Update to version 1.12.2:
  * Fix a rare build failure with UPower >= 0.99 when both systemd
    and UPower supports are enabled.
  * Some more fixes.
* Mon Jan 11 2016 sor.alexei@meowr.ru
- Separate gschemas into mate-session-manager-gschemas package.
* Mon Nov 30 2015 sor.alexei@meowr.ru
- Update to 1.12.1:
  * Get rid of dependency on libmate-desktop.
* Thu Nov  5 2015 sor.alexei@meowr.ru
- Update to 1.12.0:
  * Retrieve strings directly from gschema (requires intltool
    0.50.1).
  * Only wait 1 second max on logout/shutdown.
  * Some more fixes and cleanups.
* Fri Oct  9 2015 sor.alexei@meowr.ru
- Update to 1.11.0:
  * Add support for a new libsystemd library.
  * Add support for an optional dock, such as Plank.
  * Use org.gnome.SessionManager at /org/gnome/SessionManager as
    the D-Bus API.
  * Add option to disable overlay scrolling.
* Mon Jul 13 2015 sor.alexei@meowr.ru
- Update to 1.10.2:
  * Reintroduce missing help in session properties dialog.
  * Set XDG_CURRENT_DESKTOP env var to MATE.
  * Some bugfixes.
  * Update translations.
* Fri Jun 12 2015 sor.alexei@meowr.ru
- Update to 1.10.1:
  * Fix size of GtkScrolledWindow in session properties.
  * Check for running display manager when user switching.
- Spec cleanup.
* Wed Apr 15 2015 p.drouand@gmail.com
- Update to version 1.10.0
  * No changes since version 1.9.90
* Mon Mar 23 2015 p.drouand@gmail.com
- Update to version 1.9.90 (unstable)
  * Bugfixes release
- Remove mate-session-manager-check-for-X11-libraries.patch; merged
  on upstream release
* Sun Nov 23 2014 p.drouand@gmail.com
- Add pkgconfig(mate-desktop-2.0) build dependency; new build
  requirement
* Sun Nov 23 2014 p.drouand@gmail.com
- Update to version 1.9.3 (unstable)
  + Update translations
* Tue Nov 11 2014 p.drouand@gmail.com
- Update to version 1.9.2 (unstable)
  + Disable upower support by default (use --enable-upower if you
    need it)
- Remove "--disable-upower" coonfigure option; now the default
* Sun Oct 26 2014 p.drouand@gmail.com
- Update to version 1.9.1 (unstable)
  + No changelog available
* Wed Jul 16 2014 p.drouand@gmail.com
- Add mate-session-manager-check-for-X11-libraries.patch
- Remove useless pkgconfig(pangox); mate-session-manager doesn't
  build against pangox
- Replace pkgconfig(systemd) with systemd-devel;  systemd development
  files are needed to build with systemd support
* Sat Mar 15 2014 p.drouand@gmail.com
- Update to version 1.8.1
  + Add autostart of accessibility apps
  + Fix build with upower disabled
* Wed Mar  5 2014 p.drouand@gmail.com
- Update to version 1.8.0
  + no changes since version 1.7.90
- Do not require hicolor-icon-theme; it's wrong and unoptimized
- Remove fix-systemd-login1-support-for-hibernate-or-suspend.patch;
  fixed by upstream
* Wed Feb 19 2014 p.drouand@gmail.com
- Update to version 1.7.90 (unstable)
  + show a progress bar in logout dialog
  + add GTK3 support
  + add gnome keyring support
  + add support for X-MATE-Autostart-Delay in desktop files
* Mon Feb 10 2014 p.drouand@gmail.com
- Update to version 1.7.2 (unstable)
  + fix transifex configuration file
- Changes from version 1.7.1
  + fix makefile with automake-1.13
  + GTK3: Fix compile warning by using gdk_error_trap_pop_ignored()
  + GTK3: fix compile warning 'gtk_target_table_new_from_list' differ
    in signedness [-Wpointer-sign]
  + make upower optional
  + session: support_autostart_delay
- Changes from version 1.7.0
  + Initial GTK3 support
  + fix return value in void functions
  + fix g_type_init deprecation
  + systemd support: session_id is char*, not int
  + fix systemd-login1 support for hibernate/suspend
  + replace ghelp: with help: for user-guide
- Add systemd and remove upower build requirements
- Build with systemd and without upower support because of new
  upower API
- Build with pangox support
- Use marco as default window manager in ./configure
- Add --enable-ipv6 to configure options to get session-manager
  ipv6 capable
* Fri Sep 13 2013 p.drouand@gmail.com
-Add fix-systemd-login1-support-for-hibernate-or-suspend.patch;
  support hibernate or suspend when used with systemd
* Mon Apr 29 2013 p.drouand@gmail.com
- No version for "Recommends: %%{name}-lang"
* Fri Apr  5 2013 p.drouand@gmail.com
- Some typo fixes
* Wed Apr  3 2013 johann.luce@wanadoo.fr
- Update to version 1.6.0
  + Add Recommends:     %%{name}-lang = %%{version}-%%{release}
  + no changelog available
* Thu Mar 28 2013 p.drouand@gmail.com
- Add a branding upstream subpackage
* Fri Mar 22 2013 nmo.marques@gmail.com
- Update to version 1.5.2:
  + increase phase timeout to 30 secs
  + remove wrong g_free in systemd code
  + add initial systemd support
* Sun Feb 10 2013 johann.luce@wanadoo.fr
- Update to version 1.5.1:
  + No changelog available
- remove %%{name}-1.5.0-fix_screensaver_gschema_usage.patch
  Merged and fixed on upstream release
* Mon Nov 26 2012 nmo.marques@gmail.com
- Add %%{name}-1.5.0-fix_screensaver_gschema_usage.patch; fix
  mate-session crash due to missing key in schema; also fixes
  the Suspend/Hibernate buttons not working (because mate-session
  crashed)
* Wed Oct 10 2012 nmo.marques@gmail.com
- Update to version 1.5.0
  + drop mateconf in favor of gsettings
- Remove mateconf-2.0 from BRs and macros; use gsettings
- Add hicolor-icon-theme dependencies and macros
* Sat Sep  8 2012 nmo.marques@gmail.com
- update to version 1.4.0
  + Add pkgconfig(xau) and pkgconfig(xext) to BRs
- copypac to X11:MATE
  + minor cosmetic fixes
* Sat Jun 16 2012 nmo.marques@gmail.com
- update to version 1.2.0
  + move spec to use mateconf macros and minor cleanups
* Wed Feb 22 2012 fisiu@opensuse.org
- initial package from version 1.2.0
